@@ -12,6 +12,8 @@ from .draw import DrawerTabs
 
 
 class AddFeaturesMenuButton(QtWidgets.QPushButton):
+    FeatureAdded = pyqtSignal(str)
+
     def __init__(self, *args, m=None, **kwargs):
         super().__init__(*args, **kwargs)
 
@@ -113,8 +115,8 @@ class AddFeaturesMenuButton(QtWidgets.QPushButton):
                 else:
                     f(layer=layer, **self.props)
 
-                self.m.BM._refetch_layer(layer)
-                self.m.BM.on_draw(None)
+                self.m.f.canvas.draw_idle()
+                self.FeatureAdded.emit(str(layer))
             except Exception:
                 import traceback
 
@@ -397,6 +399,7 @@ class NewLayerWidget(QtWidgets.QFrame):
 
         m2 = self.m.new_layer(layer)
         self.NewLayerCreated.emit(layer)
+        self.new_layer_name.clear()
         # self.m.show_layer(layer)
 
         return m2
@@ -572,7 +575,7 @@ class LayerTabBar(QtWidgets.QTabBar):
                 "</ul>",
             )
 
-    def repopulate_and_activate_current(self):
+    def repopulate_and_activate_current(self, *args, **kwargs):
         self.populate()
 
         # activate the currently visible layer tab
@@ -640,19 +643,40 @@ class LayerTabBar(QtWidgets.QTabBar):
             print("can't delete the base-layer")
             return
 
+        # get currently active layers
+        active_with_transp = self.m.BM.bg_layer.split("|")
+        # strip off transparency assignments
+        active_layers = [i.split("{")[0] for i in active_with_transp]
+
+        # cleanup the layer and remove any artists etc.
         for m in list(self.m._children):
             if layer == m.layer:
                 m.cleanup()
                 m.BM._bg_layers.pop(layer, None)
 
-        if self.m.BM._bg_layer == layer:
-            try:
-                switchlayer = next((i for i in self.m.BM._bg_artists if i != layer))
-                self.m.show_layer(switchlayer)
-            except StopIteration:
-                # don't allow deletion of last layer
-                print("you cannot delete the last available layer!")
-                return
+        # in case the layer was visible, try to activate a suitable replacement
+        if layer in active_layers:
+            # if possible, show the currently active multi-layer but without
+            # the deleted layer
+            layer_idx = active_layers.index(layer)
+            active_with_transp.pop(layer_idx)
+
+            if len(active_with_transp) > 0:
+                try:
+                    self.m.show_layer(*active_with_transp)
+                except Exception:
+                    pass
+            else:
+                # otherwise switch to the first available layer
+                try:
+                    switchlayer = next(
+                        (i for i in self.m.BM._bg_artists if layer not in i.split("|"))
+                    )
+                    self.m.show_layer(switchlayer)
+                except StopIteration:
+                    # don't allow deletion of last layer
+                    print("you cannot delete the last available layer!")
+                    return
 
         if layer in list(self.m.BM._bg_artists):
             for a in self.m.BM._bg_artists[layer]:
@@ -845,7 +869,7 @@ class ArtistEditorTabs(LayerArtistTabs):
         self.m.BM._on_add_bg_artist.append(self.populate)
         self.m.BM._on_remove_bg_artist.append(self.populate)
 
-    def repopulate_and_activate_current(self):
+    def repopulate_and_activate_current(self, *args, **kwargs):
         self.populate()
 
         # activate the currently visible layer tab
@@ -1125,8 +1149,7 @@ class ArtistEditorTabs(LayerArtistTabs):
         artist.remove()
 
         self.populate_layer(layer)
-        self.m.BM._refetch_layer(layer)
-        self.m.BM.on_draw(None)
+        self.m.redraw(layer)
 
     def remove(self, artist, layer):
         @pyqtSlot()
@@ -1228,11 +1251,18 @@ class ArtistEditor(QtWidgets.QWidget):
         self.addannotation = AddAnnotationInput(m=self.m)
         self.draw = DrawerTabs(m=self.m)
 
+        # make sure the layer is properly set
+        self.set_layer()
+
         self.option_tabs = OptionTabs()
         self.option_tabs.addTab(self.addfeature, "Add Features")
         self.option_tabs.addTab(self.addannotation, "Add Annotations")
         self.option_tabs.addTab(self.draw, "Draw Shapes")
 
+        # repopulate the layer if features or webmaps are added
+        self.addfeature.selector.FeatureAdded.connect(self.artist_tabs.populate_layer)
+        self.newlayer.addwms.wmsLayerCreated.connect(self.artist_tabs.populate_layer)
+
         option_widget = QtWidgets.QWidget()
         option_layout = QtWidgets.QVBoxLayout()
         option_layout.addWidget(self.option_tabs)
@@ -1252,8 +1282,6 @@ class ArtistEditor(QtWidgets.QWidget):
 
         self.setLayout(layout)
 
-        # self.artist_tabs.populate()
-
         # connect a callback to update the layer of the feature-button
         # with respect to the currently selected layer-tab
         self.artist_tabs.tabBar().currentChanged.connect(self.set_layer)
